Continuous Colourmap Fuction
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

`pip install ccm`

## How to use

Simple paired colors and splits to generate a continuous colourmap.

``` python
hex_list = ['#2AA364', '#F5EB4D', '#9E4229', '#381D02', '#381D02', '#381D02']
float_list=[0, 0.15, .6,.75,.8,1]
cmap_1000 = get_continuous_cmap(hex_list = hex_list, float_list = float_list)
cmap_1000
```

![](index_files/figure-gfm/cell-2-output-1.png)

``` python
hex_list = ['#2AA364', '#F5EB4D', '#9E4229', '#381D02', '#381D02']
float_list=[0, 0.65, .75,.8,1]
cmap_1000 = get_continuous_cmap(hex_list = hex_list, float_list = float_list)
cmap_1000
```

![](index_files/figure-gfm/cell-3-output-1.png)
